@@ -30,9 +30,9 @@ class ErrorInfo(Error):
     name = "use-or-oper"
     code = 110
     msg: str = "Replace `x if x else y` with `x or y`"
-    categories = ["logical", "readability"]
+    categories = ("logical", "readability")
 
 
 def check(node: ConditionalExpr, errors: list[Error]) -> None:
     if is_equivalent(node.if_expr, node.cond):
-        errors.append(ErrorInfo(node.line, node.column))
+        errors.append(ErrorInfo.from_node(node))
