@@ -37,7 +37,7 @@ class ErrorInfo(Error):
     name = "use-pathlib-with-suffix"
     code = 100
     msg: str = "Use `Path(x).with_suffix(y)` instead of slice and concat"  # noqa: E501
-    categories = ["pathlib"]
+    categories = ("pathlib",)
 
 
 def check(node: OpExpr, errors: list[Error]) -> None:
@@ -53,4 +53,4 @@ def check(node: OpExpr, errors: list[Error]) -> None:
             ),
             right=StrExpr(),
         ) if is_pathlike(arg):
-            errors.append(ErrorInfo(arg.line, arg.column))
+            errors.append(ErrorInfo.from_node(arg))
